"""A Python package to implement the Gaussian Transform Regression."""

# Import the functions or classes from your modules here if you want them to be
# accessible directly from the package instead of the module. This can make
# the API easier to use.

from .compute import print_name
from .cvxpy_socket import compute_basic
